==> jc-1.4.0.tar.gz: javax/print/attribute/standard/PrinterStateReasons.h <==
// public final class javax.print.attribute.standard.PrinterStateReasons

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 412ed59d6dee5d64 javax_print_attribute_standard_PrinterStateReasons

// header file dependencies
// @dep_header java_util_HashMap

#include "java/util/HashMap.h"

#ifndef _JC_javax_print_attribute_standard_PrinterStateReasons_H_
#define _JC_javax_print_attribute_standard_PrinterStateReasons_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs	_jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$refs	_jc_javax_print_attribute_standard_PrinterStateReasons$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs	_jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$object	_jc_javax_print_attribute_standard_PrinterStateReasons$object;

typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct	_jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReasons$vmethods	_jc_javax_print_attribute_standard_PrinterStateReasons$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtable	_jc_javax_print_attribute_standard_PrinterStateReasons$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtype	_jc_javax_print_attribute_standard_PrinterStateReasons$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterStateReasons;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct _jc_javax_print_attribute_standard_PrinterStateReasons$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterStateReasons$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReasons$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterStateReasons$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReasons$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReasons$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReasons$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterStateReasons$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_javax_print_attribute_standard_PrinterStateReasons$vmethods	javax_print_attribute_standard_PrinterStateReasons;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterStateReasons$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$refs {
    _jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs	javax_print_attribute_standard_PrinterStateReasons;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs	javax_print_attribute_standard_PrinterStateReasons;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterStateReasons$object {
	_jc_javax_print_attribute_standard_PrinterStateReasons$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterStateReasons$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterStateReasons$vtype _jc_javax_print_attribute_standard_PrinterStateReasons$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterStateReasons, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterStateReasons$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterStateReasons_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/PrinterStateReasons.h <==
// public final class javax.print.attribute.standard.PrinterStateReasons

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 412ed59d6dee5d64 javax_print_attribute_standard_PrinterStateReasons

// header file dependencies
// @dep_header java_util_HashMap

#include "java/util/HashMap.h"

#ifndef _JC_javax_print_attribute_standard_PrinterStateReasons_H_
#define _JC_javax_print_attribute_standard_PrinterStateReasons_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs	_jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$refs	_jc_javax_print_attribute_standard_PrinterStateReasons$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs	_jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$object	_jc_javax_print_attribute_standard_PrinterStateReasons$object;

typedef struct _jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct	_jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReasons$vmethods	_jc_javax_print_attribute_standard_PrinterStateReasons$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtable	_jc_javax_print_attribute_standard_PrinterStateReasons$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtype	_jc_javax_print_attribute_standard_PrinterStateReasons$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterStateReasons;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterStateReasons$fields_struct _jc_javax_print_attribute_standard_PrinterStateReasons$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterStateReasons$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReasons$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterStateReasons$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReasons$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterStateReasons$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterStateReasons$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterStateReasons$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterStateReasons$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_javax_print_attribute_standard_PrinterStateReasons$vmethods	javax_print_attribute_standard_PrinterStateReasons;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterStateReasons$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterStateReasons$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$refs {
    _jc_javax_print_attribute_standard_PrinterStateReasons$sub_refs	javax_print_attribute_standard_PrinterStateReasons;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_javax_print_attribute_standard_PrinterStateReasons$sub_nonrefs	javax_print_attribute_standard_PrinterStateReasons;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterStateReasons$object {
	_jc_javax_print_attribute_standard_PrinterStateReasons$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterStateReasons$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterStateReasons$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterStateReasons$vtype _jc_javax_print_attribute_standard_PrinterStateReasons$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterStateReasons, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterStateReasons$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterStateReasons_H_ */
